ReactiveDestination constructor

const ReactiveDestination({
  1. Key? key,
  2. required String label,
  3. required IconData icon,
  4. Widget? selectedIcon,
  5. Color? indicatorColorForNavRail,
  6. ShapeBorder? indicatorShapeForNavRail,
  7. EdgeInsetsGeometry? paddingForNavRail,
  8. String? tooltipForNavBar,
})

The ReactiveDestination class represents a destination in a navigation rail or navigation bar, with customizable properties such as label, icon, selected icon, indicator color, indicator shape, padding, and tooltip.

Implementation

const ReactiveDestination({
  Key? key,
  required this.label,
  required this.icon,
  this.selectedIcon,
  this.indicatorColorForNavRail,
  this.indicatorShapeForNavRail,
  this.paddingForNavRail,
  this.tooltipForNavBar,
});