indicatorColorForNavRail property

Color? indicatorColorForNavRail
final

The indicatorColorForNavRail property in the ReactiveDestination class represents the color of the indicator that is displayed when the destination is selected in a navigation rail. It allows you to customize the color of the indicator to provide visual feedback to the user when a destination is active or selected.

Implementation

final Color? indicatorColorForNavRail;