paddingForNavRail property

EdgeInsetsGeometry? paddingForNavRail
final

The paddingForNavRail property in the ReactiveDestination class represents the padding around the destination in a navigation rail. It allows you to customize the spacing between the destination's icon and label, as well as the spacing between multiple destinations in the navigation rail. By setting the paddingForNavRail property to an EdgeInsetsGeometry object, you can define the amount of padding on each side of the destination.

Implementation

final EdgeInsetsGeometry? paddingForNavRail;