ReactiveHome constructor

const ReactiveHome({
  1. Key? key,
  2. required List<Widget> pages,
  3. required List<ReactiveDestination> reactiveDestinations,
  4. bool extendedForNavRail = true,
  5. double mobileWhenWidthIs = 500,
  6. NavigationRailLabelType labelTypeForNavRail = NavigationRailLabelType.all,
  7. Color? backgroundColor,
  8. double? elevation,
  9. Color? indicatorColor,
  10. ShapeBorder? indicatorShape,
  11. double? groupAlignmentForNavRail,
  12. double? minExtendedWidthForNavRail,
  13. double? minWidthForNavRail,
  14. Widget? leadingForNavRail,
  15. Widget? trailingForNavRail,
  16. bool? useIndicatorForNavRail,
  17. TextStyle? selectedLabelTextStyleForNavRail,
  18. TextStyle? unselectedLabelTextStyleForNavRail,
  19. IconThemeData? selectedIconThemeForNavRail,
  20. IconThemeData? unselectedIconThemeForNavRail,
  21. Color? backgroundColorForNavBar,
  22. double? elevationForNavBar,
  23. Color? indicatorColorForNavBar,
  24. ShapeBorder? indicatorShapeForNavBar,
  25. Color? backgroundColorForNavRail,
  26. double? elevationForNavRail,
  27. Color? indicatorColorForNavRail,
  28. ShapeBorder? indicatorShapeForNavRail,
  29. double? bottomNavBarHeightForNavBar,
  30. Duration? animationDurationForNavBar,
  31. Color? shadowColorForNavBar,
  32. NavigationDestinationLabelBehavior? labelBehaviorForNavBar,
})

The ReactiveHome class is a widget that displays either a ReactiveTabletView or a ReactiveMobileView based on the screen width. Meaning it helps you make reactive layouts multiple screens , like tablets , mobiles , desktop , web by adding navigation rail (for tablets and web apps) and navigation bar (for mobile phones)

Implementation

const ReactiveHome({
  super.key,
  required this.pages,
  required this.reactiveDestinations,
  this.extendedForNavRail = true,
  this.mobileWhenWidthIs = 500,
  this.labelTypeForNavRail = NavigationRailLabelType.all,
  this.backgroundColor,
  this.elevation,
  this.indicatorColor,
  this.indicatorShape,
  this.groupAlignmentForNavRail,
  this.minExtendedWidthForNavRail,
  this.minWidthForNavRail,
  this.leadingForNavRail,
  this.trailingForNavRail,
  this.useIndicatorForNavRail,
  this.selectedLabelTextStyleForNavRail,
  this.unselectedLabelTextStyleForNavRail,
  this.selectedIconThemeForNavRail,
  this.unselectedIconThemeForNavRail,
  this.backgroundColorForNavBar,
  this.elevationForNavBar,
  this.indicatorColorForNavBar,
  this.indicatorShapeForNavBar,
  this.backgroundColorForNavRail,
  this.elevationForNavRail,
  this.indicatorColorForNavRail,
  this.indicatorShapeForNavRail,
  this.bottomNavBarHeightForNavBar,
  this.animationDurationForNavBar,
  this.shadowColorForNavBar,
  this.labelBehaviorForNavBar,
});