backgroundColorForNavBar property

Color? backgroundColorForNavBar
final

The backgroundColorForNavBar parameter is used to specify the background color of the navigation bar in the ReactiveHome widget. By setting the backgroundColorForNavBar parameter, you can customize the background color of the navigation bar to match the design of your app.

Implementation

final Color? backgroundColorForNavBar;