backgroundColorForNavRail property
The backgroundColorForNavRail parameter is used to specify the background color of
the navigation rail in the ReactiveHome widget. By setting the
backgroundColorForNavRail parameter, you can customize the background color of the
navigation rail to match the design of your app.
Implementation
final Color? backgroundColorForNavRail;