bottomNavBarHeightForNavBar property

double? bottomNavBarHeightForNavBar
final

The bottomNavBarHeightForNavBar parameter is used to specify the height of the bottom navigation bar in the ReactiveHome widget when using the navigation bar layout. By setting the bottomNavBarHeightForNavBar parameter, you can customize the height of the bottom navigation bar to match the design of your app.

Implementation

final double? bottomNavBarHeightForNavBar;