build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
/// The below code is a Dart function that returns a boolean value. It checks if the value of
/// `context.csw` is greater than 500. If it is, the function returns `true`, otherwise it returns
/// `false`.
return (context.csw > mobileWhenWidthIs)
? ReactiveBigScreenView(
index: currentindex,
backgroundColor: backgroundColorForNavRail ?? backgroundColor,
elevation: elevationForNavRail ?? elevation,
indicatorColor: indicatorColorForNavRail ?? indicatorColor,
indicatorShape: indicatorShapeForNavRail ?? indicatorShape,
pages: pages,
reactiveDestinations: reactiveDestinations,
groupAlignment: groupAlignmentForNavRail,
leading: leadingForNavRail,
minExtendedWidth: minExtendedWidthForNavRail,
minWidth: minWidthForNavRail,
selectedIconTheme: selectedIconThemeForNavRail,
selectedLabelTextStyle: selectedLabelTextStyleForNavRail,
trailing: trailingForNavRail,
unselectedIconTheme: unselectedIconThemeForNavRail,
unselectedLabelTextStyle: unselectedLabelTextStyleForNavRail,
useIndicator: useIndicatorForNavRail,
key: key,
/// The below code is checking if the value of `context.csw` is greater than or equal to 1250
/// and if the value of `extendedForNavRail` is true. If both conditions are true, then it
/// sets the value of `extended` to true. Otherwise, it sets the value of `extended` to
/// false.
extended: (context.csw >= 1250 && extendedForNavRail == true)
? true
: false,
/// The below code is checking the value of `context.csw` and `labelTypeForNavRail` to
/// determine the value of `labelType`. If `context.csw` is greater than or equal to 1250
/// and `labelTypeForNavRail` is either `NavigationRailLabelType.all` or
/// `NavigationRailLabelType.selected`, then `labelType` is set to
/// `NavigationRailLabelType.none`. Otherwise, `labelType` is set to the value of
/// `labelTypeForNavRail`.
labelType: (context.csw >= 1250 &&
(labelTypeForNavRail == NavigationRailLabelType.all ||
labelTypeForNavRail ==
NavigationRailLabelType.selected))
? NavigationRailLabelType.none
: labelTypeForNavRail,
)
: ReactiveMobileView(
index: currentindex,
backgroundColor: backgroundColorForNavBar ?? backgroundColor,
elevation: elevationForNavBar ?? elevation,
indicatorColor: indicatorColorForNavBar ?? indicatorColor,
indicatorShape: indicatorShapeForNavBar ?? indicatorShape,
pages: pages,
reactiveDestinations: reactiveDestinations,
animationDuration: animationDurationForNavBar,
bottomNavBarHeight: bottomNavBarHeightForNavBar,
labelBehavior: labelBehaviorForNavBar,
shadowColor: shadowColorForNavBar,
key: key,
);
}