elevation property

double? elevation
final

The elevation parameter in the ReactiveHome class is used to specify the elevation of the widget. Elevation is a visual effect that gives the widget a sense of depth and makes it appear to be floating above the surface. The elevation parameter takes a double value, where a higher value will result in a higher elevation.

Implementation

final double? elevation;