elevationForNavBar property

double? elevationForNavBar
final

The elevationForNavBar parameter is used to specify the elevation of the navigation bar in the ReactiveHome widget. Elevation is a visual effect that gives the widget a sense of depth and makes it appear to be floating above the surface. By setting the elevationForNavBar parameter, you can customize the elevation of the navigation bar to match the design of your app.

Implementation

final double? elevationForNavBar;