extendedForNavRail property
Indicates that the NavigationRail should be in the extended state.
The extended state has a wider rail container, and the labels are
positioned next to the icons. minExtendedWidth can be used to set the
minimum width of the rail when it is in this state.
The rail will implicitly animate between the extended and normal state.
If the rail is going to be in the extended state, then the labelType
must be set to NavigationRailLabelType.none.
The default value is false.
Implementation
final bool extendedForNavRail;