indicatorColorForNavRail property

Color? indicatorColorForNavRail
final

The indicatorColorForNavRail parameter is used to specify the color of the indicator in the navigation rail. The indicator is a visual element that highlights the currently selected destination in the navigation rail. By setting the indicatorColorForNavRail parameter, you can customize the color of the indicator to match the design of your app.

Implementation

final Color? indicatorColorForNavRail;