labelBehaviorForNavBar property

NavigationDestinationLabelBehavior? labelBehaviorForNavBar
final

The labelBehaviorForNavBar parameter in the ReactiveHome class is used to specify the behavior of the labels in the navigation bar. It determines how the labels are displayed when there is limited space in the navigation bar.

Implementation

final NavigationDestinationLabelBehavior? labelBehaviorForNavBar;