pages property
The required this.pages parameter in the ReactiveHome class is used to specify the list of
pages that will be displayed in the widget. It is marked as required, which means that it must
be provided when creating an instance of the ReactiveHome widget. The pages parameter is a
list of Widget objects, representing the different pages that will be shown in the widget.
Implementation
final List<Widget> pages;