colCrossAxisAlignment property

CrossAxisAlignment colCrossAxisAlignment
final

The colCrossAxisAlignment is used to specify how the children should be aligned along the cross axis when arranged in a column. The CrossAxisAlignment enum provides different options for alignment, such as start, end, center, stretch, and baseline. The value of colCrossAxisAlignment will be used when the children are arranged in a column.

Implementation

final CrossAxisAlignment colCrossAxisAlignment;