colMainAxisAlignment property

MainAxisAlignment colMainAxisAlignment
final

colMainAxisAlignment of type MainAxisAlignment. This variable is used to specify how the children should be aligned along the main axis when arranged in a column. The MainAxisAlignment enum provides different options for alignment, such as start, end, center, spaceBetween, spaceAround, and spaceEvenly. The value of colMainAxisAlignment will be used when the children are arranged in a column.

Implementation

final MainAxisAlignment colMainAxisAlignment;