colMainAxisSize property

MainAxisSize colMainAxisSize
final

The colMainAxisSize is a variable that is used to specify the size of the Column widget along its main axis. It is of type MainAxisSize, which is an enum that provides two options: MainAxisSize.max and MainAxisSize.min.

Implementation

final MainAxisSize colMainAxisSize;