colTextbaseline property

TextBaseline? colTextbaseline
final

The colTextbaseline variable is used to specify the baseline alignment for the text within the Column widget. It accepts a value of type TextBaseline, which can be one of the following options:

Implementation

final TextBaseline? colTextbaseline;