colVerticalDirection property

VerticalDirection colVerticalDirection
final

The colVerticalDirection variable is used to specify the vertical direction in which the children should be laid out when arranged in a column. It accepts a value of type VerticalDirection, which can be either down or up. The down value indicates that the children should be laid out from top to bottom, while the up value indicates that the children should be laid out from bottom to top.

Implementation

final VerticalDirection colVerticalDirection;