colWhen property

bool Function(double screenWidth) colWhen
final

The colWhen is a function parameter that takes a double value representing the screen width and returns a bool value. It is used to determine at what point of the screen width the children should be arranged in column form. The function should return true when the condition for arranging the children in column form is satisfied, and false otherwise.

Implementation

final bool Function(double screenWidth) colWhen;