rowCrossAxisAlignment property

CrossAxisAlignment rowCrossAxisAlignment
final

rowCrossAxisAlignment of type CrossAxisAlignment. This variable is used to specify how the children should be aligned along the cross axis when arranged in a row. The CrossAxisAlignment enum provides different options for alignment, such as start, end, center, stretch, and baseline. The value of rowCrossAxisAlignment will be used when the children are arranged in a row.

Implementation

final CrossAxisAlignment rowCrossAxisAlignment;