rowTextDirection property

TextDirection? rowTextDirection
final

The rowTextDirection variable is used to specify the direction of the text within the Row widget. It accepts a value of type TextDirection, which can be either TextDirection.ltr (left-to-right) or TextDirection.rtl (right-to-left). By setting the value of rowTextDirection, you can control the direction of the text within the Row widget.

Implementation

final TextDirection? rowTextDirection;