rowTextbaseline property

TextBaseline? rowTextbaseline
final

The rowTextbaseline is a variable that is used to specify the baseline alignment for the text within the Row widget. It accepts a value of type TextBaseline, which can be one of the following options:

Implementation

final TextBaseline? rowTextbaseline;