rowWhen property

bool Function(double screenWidth) rowWhen
final

The rowWhen parameter is a function that takes a double value representing the screen width and returns a bool value. It is used to determine at what point of the screen width the children should be arranged in a row form.

Implementation

final bool Function(double screenWidth) rowWhen;