size_config library

Importing 'size_config_web' will only give you access to extension methods such as .w ,.h and .sp. Suggestion Add this dependency only to the main method to initialize initDevSize method.

Classes

SizeConfig

Extensions

SizeConfigForDouble on num
Adding extension over the double data type for easy access.