SizeConfigWebExt extension

on

Methods

ch(BuildContext context) double

Available on num, provided by the SizeConfigWebExt extension

ch stands for current height The only difference num.ch() and num.h is that num.ch() rebuilds everytime when context changes while the latter returns a fixed height even if screen height changes. ch is helpful in flutter web as windows are adjustable.
csp(BuildContext context) double

Available on num, provided by the SizeConfigWebExt extension

csp stands for current Scale independent pixels The only difference num.csp() and num.sp is that num.csp() rebuilds everytime when context changes while the latter returns a fixed width even if screen width changes. csp is helpful in flutter web as windows are adjustable.
cw(BuildContext context) double

Available on num, provided by the SizeConfigWebExt extension

cw stands for current width The only difference num.cw() and num.w is that num.cw() rebuilds everytime when context changes while the latter returns a fixed width even if screen width changes. cw is helpful in flutter web as windows are adjustable.