ch method

double ch(
  1. BuildContext context
)

ch stands for current height The only difference num.ch() and num.h is that num.ch() rebuilds everytime when context changes while the latter returns a fixed height even if screen height changes. ch is helpful in flutter web as windows are adjustable.

Implementation

double ch(BuildContext context) => this * (_mq(context).height / 100);