csp method
csp stands for current Scale independent pixels
The only difference num.csp() and num.sp is that num.csp() rebuilds
everytime when context changes while the latter returns a fixed width
even if screen width changes.
csp is helpful in flutter web as windows are adjustable.
Implementation
double csp(BuildContext context) => this * (_mq(context).width / 3) / 100;