cw method

double cw(
  1. BuildContext context
)

cw stands for current width The only difference num.cw() and num.w is that num.cw() rebuilds everytime when context changes while the latter returns a fixed width even if screen width changes. cw is helpful in flutter web as windows are adjustable.

Implementation

double cw(BuildContext context) => this * (_mq(context).width / 100);