Al enum

The code defines an enum called Al which represents different alignment options for widgets in Flutter. Each alignment option is associated with a specific AlignmentGeometry value from the flutter/widgets.dart package.

Inheritance
Available extensions

Values

c → const Al

In the given code, c is a member of the Al enum and represents the alignment option Alignment.center.

const Al(Alignment.center)
cl → const Al

In the given code, cl is a member of the Al enum and represents the alignment option Alignment.centerLeft.

const Al(Alignment.centerLeft)
cr → const Al

In the given code, cr is a member of the Al enum and represents the alignment option Alignment.centerRight.

const Al(Alignment.centerRight)
bl → const Al

In the given code, bl is a member of the Al enum and represents the alignment option Alignment.bottomLeft.

const Al(Alignment.bottomLeft)
br → const Al

In the given code, br is a member of the Al enum and represents the alignment option Alignment.bottomRight. It is associated with the Alignment.bottomRight value from the flutter/widgets.dart package.

const Al(Alignment.bottomRight)
bc → const Al

In the given code, bc is a member of the Al enum and represents the alignment option Alignment.bottomCenter.

const Al(Alignment.bottomCenter)
tl → const Al

In the given code, tl is a member of the Al enum and represents the alignment option Alignment.topLeft.

const Al(Alignment.topLeft)
tr → const Al

In the given code, tr is a member of the Al enum and represents the alignment option Alignment.topRight.

const Al(Alignment.topRight)
tc → const Al

In the given code, tc is a member of the Al enum and represents the alignment option Alignment.topCenter.

const Al(Alignment.topCenter)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value AlignmentGeometry
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Al>
A constant List of the values in this enum, in order of their declaration.