ExpandedExt extension

on

Methods

expd({int flex = 1}) Expanded

Available on Widget, provided by the ExpandedExt extension

The function expd returns an Expanded widget with a specified flex value and child widget.
expdH() SizedBox

Available on Widget, provided by the ExpandedExt extension

The function expdH returns a SizedBox widget with a height of double.infinity and a child widget wrapped in an Expanded widget.
expdW() SizedBox

Available on Widget, provided by the ExpandedExt extension

The function expdW returns a SizedBox widget with the width set to double.infinity and a child widget wrapped in an Expanded widget.
flxbl({FlexFit fit = FlexFit.loose, int flex = 1}) Flexible

Available on Widget, provided by the ExpandedExt extension

The function flxbl returns a Flexible widget with specified fit and flex properties, and the child widget.