NullStringExt extension
- on
Properties
- isNull → bool
-
Available on Object?, provided by the NullStringExt extension
This getter method checks if the string value it is called on isnull.no setter
Available on Object?, provided by the NullStringExt extension
This getter method checks if the string value it is called on isnull.