PaddingExt extension

on

Methods

p(double val) Padding

Available on Widget, provided by the PaddingExt extension

The function p returns a Padding widget with a specified padding value and the child widget.
p12() Padding

Available on Widget, provided by the PaddingExt extension

The function p12 returns a Padding widget with a padding of 12 pixels on all sides and the child widget passed to it.
p16() Padding

Available on Widget, provided by the PaddingExt extension

The function p16 returns a Padding widget with a padding of 16 pixels on all sides and the child widget passed to it.
p20() Padding

Available on Widget, provided by the PaddingExt extension

The function p20 returns a Padding widget with a padding of 20 pixels on all sides and the child widget passed to it.
p24() Padding

Available on Widget, provided by the PaddingExt extension

The function p24 returns a Padding widget with a padding of 24.0 on all sides and the child widget as its child.
ph(double p) Padding

Available on Widget, provided by the PaddingExt extension

The function ph returns a Padding widget with horizontal padding of p and the child widget.
ph12() Padding

Available on Widget, provided by the PaddingExt extension

The function ph12 returns a Padding widget with horizontal padding of 12.0.
ph16() Padding

Available on Widget, provided by the PaddingExt extension

The function ph16 returns a Padding widget with horizontal padding of 16.0.
ph20() Padding

Available on Widget, provided by the PaddingExt extension

The function ph20 returns a Padding widget with a horizontal padding of 20.
ph24() Padding

Available on Widget, provided by the PaddingExt extension

The function adds horizontal padding of 24 pixels to a widget.
pLRB({double p = 12.0, double? l, double? r, double? b}) Padding

Available on Widget, provided by the PaddingExt extension

The function pLRB returns a Padding widget with customizable padding values for left, right, and bottom, or a default value if not provided.
pLRT({double p = 12.0, double? l, double? r, double? t}) Padding

Available on Widget, provided by the PaddingExt extension

The function pLRT returns a Padding widget with customizable padding values for left, right, and top, or a default value if not provided.
pLTRB(double l, double t, double r, double b) Padding

Available on Widget, provided by the PaddingExt extension

The function pLTRB returns a Padding widget with specified left, top, right, and bottom padding values.
pOnly({double l = 0, double r = 0, double t = 0, double b = 0}) Padding

Available on Widget, provided by the PaddingExt extension

The function pOnly returns a Padding widget with specified padding values for left, right, top, and bottom.
psymtc({double h = 0.0, double v = 0.0}) Padding

Available on Widget, provided by the PaddingExt extension

The psymtc function returns a Padding widget with the specified horizontal and vertical padding values.
pv(double p) Padding

Available on Widget, provided by the PaddingExt extension

The function pv returns a Padding widget with vertical padding of p and the child widget as its child.
pv12() Padding

Available on Widget, provided by the PaddingExt extension

The function pv12 returns a Padding widget with a vertical padding of 12.0.
pv16() Padding

Available on Widget, provided by the PaddingExt extension

The function pv16 returns a Padding widget with a vertical padding of 16.0.
pv20() Padding

Available on Widget, provided by the PaddingExt extension

The function pv20 returns a Padding widget with a vertical padding of 20.
pv24() Padding

Available on Widget, provided by the PaddingExt extension

The function adds vertical padding of 24.0 units to a given widget.