p12 method

Padding p12()

The function p12 returns a Padding widget with a padding of 12 pixels on all sides and the child widget passed to it.

Implementation

Padding p12() => Padding(
      padding: const EdgeInsets.all(12.0),
      child: this,
    );