ph12 method
The function ph12 returns a Padding widget with horizontal padding of 12.0.
Implementation
Padding ph12() => Padding(
padding: const EdgeInsets.symmetric(horizontal: 12.0),
child: this,
);
The function ph12 returns a Padding widget with horizontal padding of 12.0.
Padding ph12() => Padding(
padding: const EdgeInsets.symmetric(horizontal: 12.0),
child: this,
);