ShapeChoice enum

The enum ShapeChoice { roundedrectborder, stadiumborder } is defining an enumeration called ShapeChoice with two possible values: roundedrectborder and stadiumborder. This enumeration is used to represent the different choices for the shape of a border.

Inheritance
Available extensions

Values

roundedrectborder → const ShapeChoice
stadiumborder → const ShapeChoice
beveledreactborder → const ShapeChoice

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ShapeChoice>
A constant List of the values in this enum, in order of their declaration.