SizedBoxExtWidget extension

on

Methods

szdbox({double? h, double? w, Color? col}) Widget

Available on Widget, provided by the SizedBoxExtWidget extension

Returns: A custom widget named szdbox is being returned. This widget either returns a Container with the specified color, height, width, and child widget if the color is not null, or returns a SizedBox with the specified height, width, and child widget if the color is null.