shadowColorForNavBar property

Color? shadowColorForNavBar
final

The shadowColorForNavBar parameter is used to specify the color of the shadow that appears below the navigation bar in the ReactiveHome widget. By setting the shadowColorForNavBar parameter, you can customize the color of the shadow to match the design of your app.

Implementation

final Color? shadowColorForNavBar;