clamp_dimensions library
Importing 'clamp_dimensions' will only give you access to clampInRange methods.
Functions
-
clampHeightInRange(
double minInpercent, double maxInpx, BuildContext context) → double - The function clamps a dimension value between a minimum percentage of the current height and a maximum pixel value.
-
clampTextSizeInRange(
double minInpercent, double maxInpx, BuildContext context) → double -
The function
clampTextSizeInRangereturns the minimum value betweenminInpercent.csp(context)andmaxInpx. -
clampWidthInRange(
double minInpercent, double maxInpx, BuildContext context) → double - The function clamps a dimension value between a minimum percentage and a maximum pixel value based on the current width of the context.