ReactiveDestination constructor
const
ReactiveDestination({})
The ReactiveDestination class represents a destination in a navigation rail or navigation bar,
with customizable properties such as label, icon, selected icon, indicator color, indicator shape,
padding, and tooltip.
Implementation
const ReactiveDestination({
Key? key,
required this.label,
required this.icon,
this.selectedIcon,
this.indicatorColorForNavRail,
this.indicatorShapeForNavRail,
this.paddingForNavRail,
this.tooltipForNavBar,
});