ReactiveHome constructor
const
ReactiveHome({
- Key? key,
- required List<
Widget> pages, - required List<
ReactiveDestination> reactiveDestinations, - double mobileWhenWidthIs = 500,
- Color? backgroundColor,
- double? elevation,
- Color? indicatorColor,
- ShapeBorder? indicatorShape,
The ReactiveHome class is a widget that displays either a ReactiveTabletView or a
ReactiveMobileView based on the screen width.
Meaning it helps you make reactive layouts multiple screens , like tablets , mobiles , desktop , web
by adding navigation rail (for tablets and web apps) and navigation bar (for mobile phones)
Implementation
const ReactiveHome({
super.key,
required this.pages,
required this.reactiveDestinations,
this.extendedForNavRail = true,
this.mobileWhenWidthIs = 500,
this.labelTypeForNavRail = NavigationRailLabelType.all,
this.backgroundColor,
this.elevation,
this.indicatorColor,
this.indicatorShape,
this.groupAlignmentForNavRail,
this.minExtendedWidthForNavRail,
this.minWidthForNavRail,
this.leadingForNavRail,
this.trailingForNavRail,
this.useIndicatorForNavRail,
this.selectedLabelTextStyleForNavRail,
this.unselectedLabelTextStyleForNavRail,
this.selectedIconThemeForNavRail,
this.unselectedIconThemeForNavRail,
this.backgroundColorForNavBar,
this.elevationForNavBar,
this.indicatorColorForNavBar,
this.indicatorShapeForNavBar,
this.backgroundColorForNavRail,
this.elevationForNavRail,
this.indicatorColorForNavRail,
this.indicatorShapeForNavRail,
this.bottomNavBarHeightForNavBar,
this.animationDurationForNavBar,
this.shadowColorForNavBar,
this.labelBehaviorForNavBar,
});