animationDurationForNavBar property
The animationDurationForNavBar parameter in the ReactiveHome class is used to
specify the duration of the animation when switching between different pages in
the navigation bar. By setting the animationDurationForNavBar parameter, you can
customize the duration of the animation to match the desired visual effect in your
app.
Implementation
final Duration? animationDurationForNavBar;