elevationForNavRail property
The elevationForNavRail parameter in the ReactiveHome class is used to specify
the elevation of the navigation rail in the widget. Elevation is a visual effect
that gives the widget a sense of depth and makes it appear to be floating above the
surface. By setting the elevationForNavRail parameter, you can customize the
elevation of the navigation rail to match the design of your app.
Implementation
final double? elevationForNavRail;