groupAlignmentForNavRail property
The groupAlignmentForNavRail parameter in the ReactiveHome class is used to
specify the alignment of the reactive destinations in the navigation rail. It takes
a double value between -1.0 and 1.0, where -1.0 represents aligning the
destinations to the top of the navigation rail, 0.0 represents aligning the
destinations to the center, and 1.0 represents aligning the destinations to the
bottom of the navigation rail. By setting the groupAlignmentForNavRail parameter,
you can customize the vertical alignment of the reactive destinations in the
navigation rail to match the design of your app.
Implementation
final double? groupAlignmentForNavRail;