indicatorColor property
The indicatorColor parameter in the ReactiveHome class is used to specify the
color of the indicator in the navigation rail or navigation bar. The indicator is a
visual element that highlights the currently selected destination. By setting the
indicatorColor parameter, you can customize the color of the indicator to match the
design of your app.
Implementation
final Color? indicatorColor;