indicatorColorForNavBar property
The indicatorColorForNavBar parameter is used to specify the color of the indicator
in the navigation bar. The indicator is a visual element that highlights the
currently selected destination in the navigation bar. By setting the
indicatorColorForNavBar parameter, you can customize the color of the indicator to
match the design of your app.
Implementation
final Color? indicatorColorForNavBar;