reactiveDestinations property
The reactiveDestinations; is a parameter in the ReactiveHome
class. It is used to specify the list of ReactiveDestination objects that will be displayed in
the widget. The ReactiveDestination class represents a destination in the navigation rail or
navigation bar. Each ReactiveDestination object contains properties such as an icon, label, and
route. These properties define how each destination will be displayed in the navigation rail or
navigation bar.
Implementation
final List<ReactiveDestination> reactiveDestinations;