children property
The children is a function parameter that takes two boolean parameters isRow and isCol.
It is a callback function that is responsible for building and returning a list of widgets based
on the values of isRow and isCol.
Implementation
final List<Widget> Function(bool isRow, bool isCol) children;