colTextDirection property
The colTextDirection variable is used to specify the direction of the text
within the Column widget. It accepts a value of type TextDirection, which can be either
TextDirection.ltr (left-to-right) or TextDirection.rtl (right-to-left). By setting the value
of colTextDirection, you can control the direction of the text within the Column widget.
Implementation
final TextDirection? colTextDirection;