rowMainAxisAlignment property
The rowMainAxisAlignment is used to
specify how the children should be aligned along the main axis when arranged in a row. The
MainAxisAlignment enum provides different options for alignment, such as start, end,
center, spaceBetween, spaceAround, and spaceEvenly. The value of rowMainAxisAlignment
will be used when the children are arranged in a row.
Implementation
final MainAxisAlignment rowMainAxisAlignment;