rowMainAxisSize property
The rowMainAxisSize variable is used to specify the size of the Row widget along its main
axis. It is of type MainAxisSize, which is an enum that provides two options: MainAxisSize.max
and MainAxisSize.min.
Implementation
final MainAxisSize rowMainAxisSize;