SizeConfigWebExt extension
- on
Methods
-
ch(
BuildContext context) → double -
Available on num, provided by the SizeConfigWebExt extension
ch stands for current height The only differencenum.ch()andnum.his thatnum.ch()rebuilds everytime when context changes while the latter returns a fixed height even if screen height changes. ch is helpful in flutter web as windows are adjustable. -
csp(
BuildContext context) → double -
Available on num, provided by the SizeConfigWebExt extension
csp stands for current Scale independent pixels The only differencenum.csp()andnum.spis thatnum.csp()rebuilds everytime when context changes while the latter returns a fixed width even if screen width changes. csp is helpful in flutter web as windows are adjustable. -
cw(
BuildContext context) → double -
Available on num, provided by the SizeConfigWebExt extension
cw stands for current width The only differencenum.cw()andnum.wis thatnum.cw()rebuilds everytime when context changes while the latter returns a fixed width even if screen width changes. cw is helpful in flutter web as windows are adjustable.