Al enum
The code defines an enum called Al which represents different alignment options for widgets in
Flutter. Each alignment option is associated with a specific AlignmentGeometry value from the
flutter/widgets.dart package.
Values
- c → const Al
-
In the given code,
cis a member of theAlenum and represents the alignment optionAlignment.center.const Al(Alignment.center) - cl → const Al
-
In the given code,
clis a member of theAlenum and represents the alignment optionAlignment.centerLeft.const Al(Alignment.centerLeft) - cr → const Al
-
In the given code,
cris a member of theAlenum and represents the alignment optionAlignment.centerRight.const Al(Alignment.centerRight) - bl → const Al
-
In the given code,
blis a member of theAlenum and represents the alignment optionAlignment.bottomLeft.const Al(Alignment.bottomLeft) - br → const Al
-
In the given code,
bris a member of theAlenum and represents the alignment optionAlignment.bottomRight. It is associated with theAlignment.bottomRightvalue from theflutter/widgets.dartpackage.const Al(Alignment.bottomRight) - bc → const Al
-
In the given code,
bcis a member of theAlenum and represents the alignment optionAlignment.bottomCenter.const Al(Alignment.bottomCenter) - tl → const Al
-
In the given code,
tlis a member of theAlenum and represents the alignment optionAlignment.topLeft.const Al(Alignment.topLeft) - tr → const Al
-
In the given code,
tris a member of theAlenum and represents the alignment optionAlignment.topRight.const Al(Alignment.topRight) - tc → const Al
-
In the given code,
tcis a member of theAlenum and represents the alignment optionAlignment.topCenter.const Al(Alignment.topCenter)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → AlignmentGeometry
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited