expd method
The function expd returns an Expanded widget with a specified flex value and child widget.
Args:
flex (int): The flex parameter is an optional parameter with a default value of 1. It is used
to determine the flex factor of the child widget within the Expanded widget. The flex factor
determines how much space the child widget should occupy relative to other child widgets within
the same parent widget. Defaults to 1
Implementation
Expanded expd({int flex = 1}) => Expanded(flex: flex, child: this);