PaddingExt extension
- on
Methods
-
p(
double val) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionpreturns aPaddingwidget with a specified padding value and the child widget. -
p12(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionp12returns aPaddingwidget with a padding of 12 pixels on all sides and the child widget passed to it. -
p16(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionp16returns aPaddingwidget with a padding of 16 pixels on all sides and the child widget passed to it. -
p20(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionp20returns aPaddingwidget with a padding of 20 pixels on all sides and the child widget passed to it. -
p24(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionp24returns aPaddingwidget with a padding of 24.0 on all sides and the child widget as its child. -
ph(
double p) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionphreturns aPaddingwidget with horizontal padding ofpand the child widget. -
ph12(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionph12returns aPaddingwidget with horizontal padding of 12.0. -
ph16(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionph16returns aPaddingwidget with horizontal padding of 16.0. -
ph20(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionph20returns aPaddingwidget with a horizontal padding of 20. -
ph24(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The function adds horizontal padding of 24 pixels to a widget. -
pLRB(
{double p = 12.0, double? l, double? r, double? b}) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionpLRBreturns aPaddingwidget with customizable padding values for left, right, and bottom, or a default value if not provided. -
pLRT(
{double p = 12.0, double? l, double? r, double? t}) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionpLRTreturns aPaddingwidget with customizable padding values for left, right, and top, or a default value if not provided. -
pLTRB(
double l, double t, double r, double b) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionpLTRBreturns aPaddingwidget with specified left, top, right, and bottom padding values. -
pOnly(
{double l = 0, double r = 0, double t = 0, double b = 0}) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionpOnlyreturns aPaddingwidget with specified padding values for left, right, top, and bottom. -
psymtc(
{double h = 0.0, double v = 0.0}) → Padding -
Available on Widget, provided by the PaddingExt extension
Thepsymtcfunction returns aPaddingwidget with the specified horizontal and vertical padding values. -
pv(
double p) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionpvreturns aPaddingwidget with vertical padding ofpand the child widget as its child. -
pv12(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionpv12returns aPaddingwidget with a vertical padding of 12.0. -
pv16(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionpv16returns aPaddingwidget with a vertical padding of 16.0. -
pv20(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The functionpv20returns aPaddingwidget with a vertical padding of 20. -
pv24(
) → Padding -
Available on Widget, provided by the PaddingExt extension
The function adds vertical padding of 24.0 units to a given widget.