p12 method
The function p12 returns a Padding widget with a padding of 12 pixels on all sides and the
child widget passed to it.
Implementation
Padding p12() => Padding(
padding: const EdgeInsets.all(12.0),
child: this,
);
The function p12 returns a Padding widget with a padding of 12 pixels on all sides and the
child widget passed to it.
Padding p12() => Padding(
padding: const EdgeInsets.all(12.0),
child: this,
);