Shaper class
The Shaper class in Dart is a utility class that helps create different types of shape borders for
widgets.
- Annotations
Properties
- curv10 → Shaper
-
This method sets the corner radius of all four corners of the border to the
specified value (10 in this case). So,
curv10is a shorthand way to set the corner radius of all corners to 10.no setter - curv15 → Shaper
-
This method sets the corner radius of all four corners of the border to the
specified value (15 in this case). So,
curv15is a shorthand way to set the corner radius of all corners to 15.no setter - curv20 → Shaper
-
This method sets the corner radius of all four corners of the border to the
specified value (20 in this case). So,
curv20is a shorthand way to set the corner radius of all corners to 20.no setter - curv25 → Shaper
-
This method sets the corner radius of all four corners of the border to the
specified value (25 in this case). So,
curv25is a shorthand way to set the corner radius of all corners to 25.no setter - curvBL10 → Shaper
-
It is a shorthand way to set the bottom left corner radius of the border to a specific value (10 in this case).
no setter
- curvBL15 → Shaper
-
It is a shorthand way to set the bottom left corner radius of the border to a specific value (15 in this case).
no setter
- curvBL20 → Shaper
-
It is a shorthand way to set the bottom left corner radius of the border to a specific value (20 in this case).
no setter
- curvBL25 → Shaper
-
It is a shorthand way to set the bottom left corner radius of the border to a specific value (25 in this case).
no setter
- curvBR10 → Shaper
-
It is a shorthand way to set the bottom right corner radius of the border to a specific value (10 in this case).
no setter
- curvBR15 → Shaper
-
It is a shorthand way to set the bottom right corner radius of the border to a specific value (15 in this case).
no setter
- curvBR20 → Shaper
-
It is a shorthand way to set the bottom right corner radius of the border to a specific value (20 in this case).
no setter
- curvBR25 → Shaper
-
It is a shorthand way to set the bottom corner radius of the border to a specific value (25 in this case).
no setter
- curvTL10 → Shaper
-
It is a shorthand way to set the top right corner radius of the border to a specific value (10 in this case).
no setter
- curvTL15 → Shaper
-
It is a shorthand way to set the top left corner radius of the border to a specific value (15 in this case).
no setter
- curvTL20 → Shaper
-
It is a shorthand way to set the top left corner radius of the border to a specific value (20 in this case).
no setter
- curvTL25 → Shaper
-
It is a shorthand way to set the top left corner radius of the border to a specific value (25 in this case).
no setter
- curvTR10 → Shaper
-
It is a shorthand way to set the top left corner radius of the border to a specific value (10 in this case).
no setter
- curvTR15 → Shaper
-
It is a shorthand way to set the top right corner radius of the border to a specific value (15 in this case).
no setter
- curvTR20 → Shaper
-
It is a shorthand way to set the top right corner radius of the border to a specific value (20 in this case).
no setter
- curvTR25 → Shaper
-
It is a shorthand way to set the top right corner radius of the border to a specific value (25 in this case).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
col(
Color color) → Shaper - The function "col" sets the border color of the shape.
-
create(
) → ShapeBorder - The function creates a shape border based on the user's choice of shape.
-
curveAll(
double rad) → Shaper -
The function
curveAllsets the corner radius of all corners to a given value. -
curveBttm(
double rad) → Shaper -
The function
curveBttmcurves only bottom corners. -
curveLft(
double rad) → Shaper -
The function
curveLftsets the horizontal left border radius of a shape to a given value. -
curveOnly(
{double? tl, double? tr, double? bl, double? br}) → Shaper -
The function
curveOnlytakes in optional parameters for the top left, top right, bottom left, and bottom right border radii and returns aBorderRadiusobject with only those specified radii. -
curveRgt(
double rad) → Shaper -
The function
curveRgtsets the horizontal right border radius of a shape to a given value. -
curveTop(
double rad) → Shaper -
The function
curveTopcurves only top corners. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
width(
double width) → Shaper - The function sets the border width of the shape.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- bevldrectbrdr → Shaper
-
Use this to get the instance of
BeveledRectangleBorder()no setter - roundrectbrdr → Shaper
-
Use this to get the instance of
RoundedRectangleBorder()no setter - stadiumbrdr → Shaper
-
Use this to get the instance of
StadiumBorder()no setter