indicatorShapeForNavRail property
The indicatorShapeForNavRail property in the ReactiveDestination class
represents the shape of the indicator that is displayed when the destination is
selected in a navigation rail. It allows you to customize the shape of the
indicator to provide visual feedback to the user when a destination is active
or selected. The indicatorShapeForNavRail property should be set to a
ShapeBorder object, such as RoundedRectangleBorder or CircleBorder, to
define the shape of the indicator.
Implementation
final ShapeBorder? indicatorShapeForNavRail;